:mod:`trac.ticket.model`
========================

.. automodule :: trac.ticket.model
   :members:

Components
----------

.. autoclass :: MilestoneCache
   :members:
   :exclude-members: factory

   .. automethod ::
      factory(name_due_completed_description_tuple, milestone_component=None)

.. autoclass :: Component
   :members:

.. autoclass :: Milestone
   :members:

.. autoclass :: Priority
   :members:

.. autoclass :: Report
   :members:

.. autoclass :: Resolution
   :members:

.. autoclass :: Severity
   :members:

.. autoclass :: Type
   :members:

.. autoclass :: Version
   :members:

Miscellaneous
-------------

.. autofunction :: simplify_whitespace
